Functions
- calculate_
mouse_ list_ select_ index - calculate_
viewport_ corrected_ cursor_ position - centered_
rect_ with_ length - centered_
rect_ with_ percentage - check_
for_ card_ drag_ and_ get_ style - check_
if_ active_ and_ get_ style - Checks for popup to return inactive style if not returns the style passed
- check_
if_ mouse_ is_ in_ area - get_
button_ style - get_
mouse_ focusable_ field_ style - Returns the style for the field based on the current focus and mouse position and sets the focus if the mouse is in the field area
- get_
mouse_ focusable_ field_ style_ with_ vertical_ list_ selection - get_
scrollable_ widget_ row_ bounds - top_
left_ rect